# remirepo/Fedora spec file for php-zendframework-zend-math
#
# Copyright (c) 2015-2018 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global bootstrap    0
%global gh_commit    558806e338ee68575fbe69489c9dcb6d57a1dae0
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner     zendframework
%global gh_project   zend-math
%global php_home     %{_datadir}/php
%global library      Math
%if %{bootstrap}
%global with_tests   0%{?_with_tests:1}
%else
%global with_tests   0%{!?_without_tests:1}
%endif

Name:           php-%{gh_owner}-%{gh_project}
Version:        3.1.0
Release:        1%{?dist}
Summary:        Zend Framework %{library} component

Group:          Development/Libraries
License:        BSD
URL:            https://zendframework.github.io/%{gh_project}/
Source0:        %{gh_commit}/%{name}-%{version}-%{gh_short}.tgz
Source1:        makesrc.sh

BuildArch:      noarch
# Tests
%if %{with_tests}
BuildRequires:  php(language) >= 5.6
BuildRequires:  php-bcmath
BuildRequires:  php-gmp
BuildRequires:  php-mbstring
BuildRequires:  php-pcre
BuildRequires:  php-spl
# test suite hangs without (need investigation)
BuildRequires:  php-mcrypt
# From composer, "require-dev": {
#        "phpunit/phpunit": "^5.7.27 || ^6.5.8 || ^7.1.2",
#        "zendframework/zend-coding-standard": "~1.0.0"
# remirepo:1
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
BuildRequires: (php-composer(paragonie/random_compat)           >= 2.0.11 with php-composer(paragonie/random_compat)           <  3)
%global phpunit %{_bindir}/phpunit7
BuildRequires:  phpunit7 >= 7.1.2
# remirepo:6
%else
BuildRequires:  php-composer(paragonie/random_compat)           <  3
BuildRequires:  php-composer(paragonie/random_compat)           >= 2.0.11
%global phpunit %{_bindir}/phpunit6
BuildRequires:  phpunit6 >= 6.5.8
%endif
# Autoloader
BuildRequires:  php-fedora-autoloader-devel
%endif

# From composer, "require": {
#        "php": "^5.6 || ^7.0",
#        "ext-mbstring": "*",
#        "paragonie/random_compat": "^2.0.11"
Requires:       php(language) >= 5.6
Requires:       php-mbstring
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
Requires:      (php-composer(paragonie/random_compat)           >= 2.0.11 with php-composer(paragonie/random_compat)           <  3)
# remirepo:4
%else
Requires:       php-composer(paragonie/random_compat)           <  3
Requires:       php-composer(paragonie/random_compat)           >= 2.0.11
%endif
# From phpcompatinfo report for version 3.1.0
Requires:       php-mbstring
Requires:       php-pcre
Requires:       php-spl
%if ! %{bootstrap}
# From composer, "suggest": {
#        "ext-bcmath": "If using the bcmath functionality",
#        "ext-gmp": "If using the gmp functionality",
Requires:       php-bcmath
Requires:       php-gmp
# Autoloader
Requires:       php-composer(fedora/autoloader)
%endif

Obsoletes:      php-ZendFramework2-%{library} < 2.5
Provides:       php-ZendFramework2-%{library} = %{version}
Provides:       php-composer(%{gh_owner}/%{gh_project}) = %{version}
Provides:       php-autoloader(%{gh_owner}/%{gh_project}) = %{version}


%description
Zend\Math provides general mathematical functions.
So far the supported functionalities are:
* Zend\Math\Rand, a random number generator;
* Zend\Math\BigInteger, a library to manage big integers.

Documentation: https://zendframework.github.io/%{gh_project}/


%prep
%setup -q -n %{gh_project}-%{gh_commit}

mv LICENSE.md LICENSE

%build
: Create dependency autoloader - deprecated
cat << 'EOF' | tee autoload.php
<?php
require_once '%{php_home}/random_compat/autoload.php';
EOF

: Create autoloader
phpab --template fedora --output src/autoload.php src
cat << 'EOF' | tee -a src/autoload.php
\Fedora\Autoloader\Dependencies::required([
    '%{php_home}/random_compat/autoload.php',
]);
EOF



%install
mkdir -p   %{buildroot}%{php_home}/Zend/
cp -pr src %{buildroot}%{php_home}/Zend/%{library}

install -m644 autoload.php %{buildroot}%{php_home}/Zend/%{library}-autoload.php


%check
%if %{with_tests}
mkdir vendor
cat << 'EOF' | tee vendor/autoload.php
<?php
require_once '%{buildroot}%{php_home}/Zend/%{library}/autoload.php';
\Fedora\Autoloader\Autoload::addPsr4('ZendTest\\%{library}\\', dirname(__DIR__) . '/test');
EOF

ret=0
for cmdarg in "php %{phpunit}" "php56 %{_bindir}/phpunit" "php70 %{_bindir}/phpunit6" php71 php72; do
  if which $cmdarg; then
    set $cmdarg
    $1 ${2:-%{_bindir}/phpunit7} --verbose || ret=1
  fi
done
exit $ret
%else
: Test suite disabled
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc *.md
%doc composer.json
%dir %{php_home}/Zend
%{php_home}/Zend/%{library}
%{php_home}/Zend/%{library}-autoload.php


%changelog
* Fri Apr 27 2018 Remi Collet <remi@remirepo.net> - 3.1.0-1
- update to 3.1.0
- raise dependency on PHP 5.6
- raise dependency on paragonie/random_compat 2.0.11
- add dependency on mbstring
- use range dependencies on F27+
- switch to phpunit6 or phpunit7

* Thu Nov 23 2017 Remi Collet <remi@fedoraproject.org> - 3.0.0-4
- switch from zend-loader to fedora/autoloader

* Wed Jun 29 2016 Remi Collet <remi@fedoraproject.org> - 3.0.0-1
- update to 3.0.0 for ZendFramework 3
- add dependencies autoloader
- add dependency on paragonie/random_compat
- drop dependency on ircmaxell/random-lib

* Fri Apr  8 2016 Remi Collet <remi@fedoraproject.org> - 2.7.0-1
- update to 2.7.0
- add mandatory dependency on ircmaxell/random-lib

* Wed Feb  3 2016 Remi Collet <remi@fedoraproject.org> - 2.6.0-1
- update to 2.6.0
- drop dependency on zend-servicemanager

* Thu Dec 17 2015 Remi Collet <remi@fedoraproject.org> - 2.5.2-1
- update to 2.5.2
- raise minimal php version to 5.5

* Tue Aug  4 2015 Remi Collet <remi@fedoraproject.org> - 2.5.1-1
- initial package
